@@ -553,6 +553,37 @@ class Node(BaseModel):
         self.hydrate(new_node=node)
         return True
 
+    @classmethod
+    async def delete_many(
+        cls: T.Type[NodeModel],
+        *,
+        nodes: T.List[NodeModel],
+        given_resolver: ResolverType = None,
+    ) -> bool:
+        if not cls.GQL.delete_function_name:
+            raise GQLException(f"No delete function given for {cls.GQL.typename}")
+        resolver = given_resolver or cls.GQL.resolver()
+        query_str = resolver.make_delete_mutation_str()
+        variables = {
+            "filter": {cls.GQL.uid_field_name: [node._uid for node in nodes]},
+        }
+        j = await cls.GQL.dgraph_client.execute(
+            query_str=query_str, variables=variables
+        )
+        node_d_lst = j["data"][f"{cls.GQL.delete_function_name}"][
+            cls.GQL.payload_node_name
+        ]
+        if not node_d_lst:
+            # raise Exception("No update was registered!!")
+            print("NO DELETE WAS REGISTERED")
+            return False
+
+        for og_node, node_d in zip(nodes, node_d_lst):
+            new_node = resolver.parse_obj_nested(node_d)
+            new_node._deleted = True
+            og_node.hydrate(new_node=new_node)
+        return True
+
 
 from .resolver import Resolver
 
